@@ -67,7 +67,6 @@ KEYTYPE_BRANCHALPHABET,
 KEYTYPE_SETTINGS,
 KEYTYPE_SPELL,
 KEYTYPE_WORDCOMPLETE,
-KEYTYPE_COMMANDPREDICT,
 KEYTYPE_WINDOW,
 KEYTYPE_MOVERESIZE,
 KEYTYPE_POINTERCONTROL,
@@ -231,7 +230,6 @@ typedef struct GokKey{
 	gint BottomWin;
 	gint LeftWin;
 	gint RightWin;
-	struct GokKey* pMimicKey;
 
 	struct GokKey* pKeyNext;
 	struct GokKey* pKeyPrevious;
