@@ -39,6 +39,8 @@
 #include <string.h>
 #include <stdlib.h>
 #include <libspi/keymasks.h>
+#include <glib.h>
+#include <glib/gi18n.h>
 #include "main.h"
 #include "gok-spy.h"
 #include "gok-log.h"
